//#define NU32_STANDALONE  // uncomment if program is standalone, not bootloaded
#include "NU32.h"          // plib.h, config bits, constants, funcs for startup and UART

unsigned oldB, oldF, newB, newF;   // to hold the port B and F reads

void __ISR(_CHANGE_NOTICE_VECTOR, IPL3SOFT) CNISR(void) { // INT step 1
  newB = mPORTBRead();    // since pins on port B and F are being monitored ...
  newF = mPORTFRead();    // ... by CN, must read both to allow continued functioning
  // ... do something here with oldB, oldF, newB, newF ...
  oldB = newB;            // save the current values for future use
  oldF = newF;
  LATBINV = 0xF0;         // toggle buffered RB4, RB5 and open-drain RB6, RB7
  INTClearFlag(_CHANGE_NOTICE_IRQ);    // clear the interrupt flag
}

void main(void) {
  NU32_Startup(); // cache on, min flash wait, interrupts on, LED/button init, UART init

  mPORTBSetPinsAnalogIn(BIT_8|BIT_9|BIT_10|BIT_11|BIT_12|BIT_13|BIT_14|BIT_15);
  mPORTBSetPinsDigitalOut(BIT_4 | BIT_5 | BIT_6 | BIT_7);
  mPORTBSetPinsDigitalIn(BIT_0 | BIT_1 | BIT_2 | BIT_3);
  mPORTBOpenDrainOpen(BIT_6 | BIT_7);

  INTDisableInterrupts(); // INT step 2
  // INT step 3: turn on CN and choose pins for CN (also choose pull-ups)
  mCNOpen(CN_ON, CN2_ENABLE | CN17_ENABLE | CN18_ENABLE,
          CN2_PULLUP_ENABLE | CN3_PULLUP_ENABLE | CN17_PULLUP_ENABLE);

  oldB = mPORTBRead();
  oldF = mPORTFRead();
  mPORTBWrite(0x0050);

  INTSetVectorPriority(_CHANGE_NOTICE_VECTOR, 3);    // INT step 4: priority
  INTSetVectorSubPriority(_CHANGE_NOTICE_VECTOR, 2); // INT step 4: subpriority
  INTClearFlag(_CHANGE_NOTICE_IRQ);                  // INT step 5
  INTEnable(_CHANGE_NOTICE_IRQ, INT_ENABLED);        // INT step 6
  INTEnableSystemMultiVectoredInt();                 // INT step 7

  while(1);              // infinite loop
}
